==> wizcloud-api-1.0.2.tgz: package/examples/DocumentApiExample.js <==
////////////////////////////////////////////////////////////basic required code 
//Must to configure private data on apiConfig.js file
const  wizlib = require('../wizApiExternalLib.js');
//var express = require('express');
//var router = express.Router();
var fs   = require('fs');
var myObjData;
			try{
				myObjData=JSON.parse(fs.readFileSync('../apiConfig.js'));
			}catch(e){ //no config file take from fs
				console.log(e);				
      }
var myDBname=myObjData.WizcloudApiDBName;
wizlib.init(myObjData.WizcloudApiPrivateKey, myObjData.WizcloudApiServer);
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//Jason data example- client responsibility
let stock= {
    StockID:'0',
    DocumentID:'1',
    DocNumber:'1',
    AccountKey:'111',
    AccountName:'name acc 111', 
    Warehouse:'1',
    Agent:'1', 
    DiscountPrc:'10',
    Tftal:'0',
    Phone: '',
    Details:'my doc details',
    Osek874:'123456789',
    ValueDate:'2019-11-30',
    
    moves:
    [
      {                
        ItemKey:'11',
				ItemName:'name item 11', 
				Price:'1050', 
				Quantity:'2', 
				Tftal:'2100', 
				DiscountPrc:'5', 
				CurrencyCode: '$',
				Rate:'3.7' ,
				Agent:'1',
				Warehouse:'1',
				Details:'my details 11'
       },
      {                    
        ItemKey:'33',
				ItemName:'name item 33', 
				Price:'20', 
				Quantity:'5', 
				Tftal:'100'
      }
    ]          
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Api methods
async function createDocument(){
	let apiRes = await wizlib.createDocument(myDBname,{rows:stock,issueStock:false, deleteTemp:true}); 
	console.log(apiRes)
}

createDocument();

async function issueDoc(){
	let apiRes = await wizlib.issueDoc(myDBname, { stockID: 744});
	console.log(apiRes)
}
async function delDocument(){
	let apiRes = await wizlib.delDocument(myDBname, { stockID: 768});
	console.log(apiRes)
}
async function showDocument(){
	let apiRes = await wizlib.showDocument(myDBname, { stockID: 768});
	console.log(apiRes)
}


/*
router.get('/', async function (req, res) {
    //console.log("ZZZZZ createDocument")
    let apiRes = await wizlib.createDocument(myDBname,{rows:stock,issueStock:false, deleteTemp:true}); 
    res.json(apiRes);
})

router.get("/issue", async function(req, res) {
	let apiRes = await wizlib.issueDoc(myDBname, { stockID: 744});
	res.json(apiRes);
});
router.get("/del", async function(req, res) {
	let apiRes = await wizlib.delDocument(myDBname, { stockID: 768});
	res.json(apiRes);
});
router.get("/show", async function(req, res) {
	let apiRes = await wizlib.showDocument(myDBname, { stockID: 768});
	res.json(apiRes);
});

module.exports = router;
 */

==> wizcloud-api-1.0.15.tgz: package/examples/DocumentApiExample.js <==
////////////////////////////////////////////////////////////basic required code 
//Must to configure private data on apiConfig.js file
const wizlib = require("wizcloud-api");
var fs   = require('fs');
var myObjData;
			try{
				myObjData=JSON.parse(fs.readFileSync('apiConfig.js'));
			}catch(e){ //no config file take from fs
				console.log(e);				
      }
var myDBname=myObjData.WizcloudApiDBName;
wizlib.init(myObjData.WizcloudApiPrivateKey, myObjData.WizcloudApiServer);
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//Jason data example- client responsibility
let stock= {
    StockID:'0',
    DocumentID:'1',
    DocNumber:'1',
    AccountKey:'111',
    AccountName:'name acc 111', 
    Warehouse:'1',
    Agent:'1', 
    DiscountPrc:'10',
    Tftal:'0',
    Phone: '',
    Details:'my doc details',
    Osek874:'123456789',
    ValueDate:'2019-11-30',
    
    moves:
    [
      {                
        ItemKey:'11',
				ItemName:'name item 11', 
				Price:'1050', 
				Quantity:'2', 
				Tftal:'2100', 
				DiscountPrc:'5', 
				CurrencyCode: '$',
				Rate:'3.7' ,
				Agent:'1',
				Warehouse:'1',
				Details:'my details 11'
       },
      {                    
        ItemKey:'33',
				ItemName:'name item 33', 
				Price:'20', 
				Quantity:'5', 
				Tftal:'100'
      }
    ]          
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//Api methods
async function createDocument(){
	let apiRes = await wizlib.createDocument(myDBname,{rows:stock,issueStock:false, deleteTemp:true}); 
	console.log(apiRes);
	fs.writeFile('myApiRes.txt', JSON.stringify(apiRes), (err) => {
    if (err) throw err;
		console.log('See resaults in myApiRes.txt');
	});
}

createDocument();

async function issueDoc(){
	let apiRes = await wizlib.issueDoc(myDBname, { stockID: 744});
	console.log(apiRes)
}
async function delDocument(){
	let apiRes = await wizlib.delDocument(myDBname, { stockID: 768});
	console.log(apiRes)
}
async function showDocument(){
	let apiRes = await wizlib.showDocument(myDBname, { stockID: 768});
	console.log(apiRes)
}
